/*

  IR Remote Controller Finder

  Parts required:
  - Arduino Board
  - IR Remote Controller

  Libraries required:
  - IRremote 2.2.3

  Programming by : René Rasmussen
  Website : www.it-teknolog.dk
  Contact : renerasmussen@it-teknolog.dk
  Date : 21 Dec 2019
  Version : v1.0

*/

#include <IRremote.h>                                         // import library IRremote

const int RECV_PIN = 7;                                       // set RESV_PIN to digital port 7
IRrecv irrecv(RECV_PIN);                                      // create object IRrecv from irrrecv with digital port 7
decode_results results;                                       // set the value of results to value from decode_results

void setup() {
  Serial.begin(9600);                                         // start Serial Monitor communication
  irrecv.enableIRIn();                                        // set irrecv to receive
}

void loop() {
  if (irrecv.decode(&results)) {                              // if irrecv.decode = a result do
    Serial.println(results.value, HEX);                       // print results.value to Serial Monitor
    switch (results.decode_type) {                            // do case
      case NEC: Serial.println("NEC"); break ;                // if result is NEC remote print NEC to Serial Monitor
      case SONY: Serial.println("SONY"); break ;              // and so on with all remotes
      case RC5: Serial.println("RC5"); break ;
      case RC6: Serial.println("RC6"); break ;
      case DISH: Serial.println("DISH"); break ;
      case SHARP: Serial.println("SHARP"); break ;
      case JVC: Serial.println("JVC"); break ;
      case SANYO: Serial.println("SANYO"); break ;
      case MITSUBISHI: Serial.println("MITSUBISHI"); break ;
      case SAMSUNG: Serial.println("SAMSUNG"); break ;
      case LG: Serial.println("LG"); break ;
      case WHYNTER: Serial.println("WHYNTER"); break ;
      case AIWA_RC_T501: Serial.println("AIWA_RC_T501"); break ;
      case PANASONIC: Serial.println("PANASONIC"); break ;
      case DENON: Serial.println("DENON"); break ;
      default:
      case UNKNOWN: Serial.println("UNKNOWN"); break ;        // if result is unknown print to Serial Monitor
    }
    irrecv.resume();                                          // resume receiving from irrecv
  }
}
